#ifndef PRAYERTIMESETTINGS_H
#define PRAYERTIMESETTINGS_H

#include <QString>
#include <QSettings>


class PrayerTimeSettings
{
public:
    PrayerTimeSettings();
    double getLatitude();
    double getLongitude();
    double getTimeZone();
    int getCalcMethod();
    int getJuristicMethod();
    int getLatMethod();
    int getTimeFormat();
    bool setupCompleted();
    void update(QString lat, QString longitude, QString timeZone, int calcMethod, int jMethod, int latMethod, int timeFormat);

private:
    double lat;
    double longitude;
    double timeZone;
    int calcMethod;
    int juristicMethod;
    int latMethod;
    int timeFormat;
};

#endif // PRAYERTIMESETTINGS_H
